==> alfresco-repository-23.6.0.19-sources.jar: org/alfresco/repo/virtual/config/NodeRefPathExpressionFactory.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.virtual.config;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
 * Spring context {@link NodeRefPathExpression} factory bean.<br>
 * It creates {@link NodeRefPathExpression} instances configured with the
 * spring context defined {@link NodeRefResolver} and the given set of spring
 * configured {@link NodeRefContext}s.
 */
public class NodeRefPathExpressionFactory 
{
    private Map<String, NodeRefContext> contextsMap = Collections.emptyMap();

    private NodeRefResolver resolver;

    public void setResolver(NodeRefResolver resolver)
    {
        this.resolver = resolver;
    }

    public void setNodeRefContexts(Set<NodeRefContext> nodeRefContexts)
    {
        this.contextsMap = new HashMap<String, NodeRefContext>();

        for (NodeRefContext nodeRefContext : nodeRefContexts)
        {
            this.contextsMap.put(nodeRefContext.getContextName(),
                                 nodeRefContext);
        }
    }

    public NodeRefPathExpression createInstance()
    {
        return new NodeRefPathExpression(resolver,
                                           this.contextsMap);
    }

}

==> alfresco-repository-25.3.0.69-sources.jar: org/alfresco/repo/virtual/config/NodeRefPathExpressionFactory.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.virtual.config;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
 * Spring context {@link NodeRefPathExpression} factory bean.<br>
 * It creates {@link NodeRefPathExpression} instances configured with the spring context defined {@link NodeRefResolver} and the given set of spring configured {@link NodeRefContext}s.
 */
public class NodeRefPathExpressionFactory
{
    private Map<String, NodeRefContext> contextsMap = Collections.emptyMap();

    private NodeRefResolver resolver;

    public void setResolver(NodeRefResolver resolver)
    {
        this.resolver = resolver;
    }

    public void setNodeRefContexts(Set<NodeRefContext> nodeRefContexts)
    {
        this.contextsMap = new HashMap<String, NodeRefContext>();

        for (NodeRefContext nodeRefContext : nodeRefContexts)
        {
            this.contextsMap.put(nodeRefContext.getContextName(),
                    nodeRefContext);
        }
    }

    public NodeRefPathExpression createInstance()
    {
        return new NodeRefPathExpression(resolver,
                this.contextsMap);
    }

}
